@@ -4,7 +4,10 @@ use std::borrow::Cow;
 use std::fs::File;
 use std::{error::Error, io};
 
+#[cfg(feature = "clap")]
 use clap::Parser;
+
+#[cfg(feature = "ui")]
 use crossterm::{
     event::{self, DisableMouseCapture, EnableMouseCapture, Event, KeyCode},
     execute,
@@ -13,6 +16,7 @@ use crossterm::{
         LeaveAlternateScreen,
     },
 };
+#[cfg(feature = "ui")]
 use tui::{
     backend::{Backend, CrosstermBackend},
     layout::{Alignment, Constraint, Direction, Layout},
@@ -21,22 +25,21 @@ use tui::{
     Frame, Terminal,
 };
 
-mod card;
-use card::Card;
-
-mod app;
-use app::App;
-
-mod scores;
-pub use scores::Scores;
-
-mod opts;
-pub use opts::Opts;
+use flashed::app::App;
+use flashed::card::Card;
+use flashed::opts::Opts;
 
+#[cfg(feature = "ui")]
 mod theme;
 
 pub type CardCow<'a> = Cow<'a, Card>;
 
+#[cfg(not(feature = "ui"))]
+fn main() {
+    compile_error!("Really sorry but you don't have a ui enabled.");
+}
+
+#[cfg(feature = "ui")]
 fn main() -> Result<(), Box<dyn Error>> {
     let opts = Opts::parse();
 
@@ -76,6 +79,7 @@ fn main() -> Result<(), Box<dyn Error>> {
     Ok(())
 }
 
+#[cfg(feature = "ui")]
 fn run_app<B: Backend>(
     terminal: &mut Terminal<B>,
     mut app: App,
@@ -109,6 +113,7 @@ fn run_app<B: Backend>(
     Ok(true)
 }
 
+#[cfg(feature = "ui")]
 fn ui<B: Backend>(f: &mut Frame<B>, app: &App) {
     let chunks = Layout::default()
         .direction(Direction::Vertical)
@@ -131,6 +136,7 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &App) {
 
 /// Creates the instructions to be shown at the top
 /// of the app.
+#[cfg(feature = "ui")]
 fn create_instructions(_app: &App) -> impl Widget {
     // Create the help message
     //
@@ -157,6 +163,7 @@ fn create_instructions(_app: &App) -> impl Widget {
 }
 
 /// Creates the card for the user to flip
+#[cfg(feature = "ui")]
 fn create_card(app: &App) -> impl Widget + '_ {
     let mut card;
 
@@ -175,6 +182,7 @@ fn create_card(app: &App) -> impl Widget + '_ {
 }
 
 /// Creates the stats about the card and deck
+#[cfg(feature = "ui")]
 fn create_stats(app: &App) -> impl Widget + '_ {
     // Write the stats
     let msg = vec![
